import { deleteSessionTokenCookie, setSessionTokenCookie } from "$lib/auth/cookie";
import { validateSessionToken } from "$lib/auth/session";
import type { Handle } from "@sveltejs/kit";

export const handle: Handle = async ({ event, resolve }) => {
	const db = event.platform?.env?.TCL_GUESSR_D1 ?? null;
	const token = event.cookies.get("session") ?? null;

	if (db === null || token === null) {
		event.locals.session = null;
		event.locals.user = null;
		return resolve(event);
	}

	const { session, user } = await validateSessionToken(token, db);
	if (session !== null) {
		setSessionTokenCookie(event.cookies, token, session.expiresAt);
	} else {
		deleteSessionTokenCookie(event.cookies);
	}

	event.locals.session = session;
	event.locals.user = user;
	return resolve(event);
};
