import { getMergedStops, getMetro, getTram, parseOptions } from "$lib";
import type { MapData } from "$lib/types";
import type { RequestHandler } from "./$types";

export const GET: RequestHandler = async ({ url }) => {
	const options = parseOptions(url);
	const mapData: MapData = { lines: [], stops: [] };

	if (options.mode !== "extreme demon ultra miguel") {
		switch (options.stopsType) {
			case "metro":
				mapData.lines = await getMetro();
				break;
			case "tram":
				mapData.lines = await getTram();
				break;
		}

		if (options.mode === "easy") {
			const crossingStops = await getMergedStops(options.stopsType);

			const strippedStops: [number, number][] = crossingStops.map((f) => {
				const coords = (f.geometry as GeoJSON.Point).coordinates;
				return [coords[1], coords[0]];
			});

			mapData.stops = strippedStops;
		}
	}

	return Response.json(mapData);
};
