import type { PageServerLoad } from "./$types";
import { error } from "@sveltejs/kit";

interface JoinedRoundScore {
	mode: string;
	stops_type: string;
	total_score: number;
	name: string;
	points: number;
	distance: number;
	stop_name: string;
}

export const load: PageServerLoad = async ({ locals, url, platform }) => {
	const db = platform?.env?.TCL_GUESSR_D1;
	if (!db) error(500, "could not connect to d1");

	const gameId = url.searchParams.get("gameId");
	if (!gameId) error(400, "gameId was not specified");

	const { results } = await db
		.prepare(
			"SELECT game.mode, game.stops_type, game.total_score, user.name, round.points, round.distance, round.stop_name FROM game INNER JOIN round ON round.game_id = game.id LEFT JOIN user ON user.id = game.user_id WHERE game.id = ?;",
		)
		.bind(gameId)
		.all<JoinedRoundScore>();

	return { rounds: results, gameId, loggedIn: locals.user !== null };
};
